\name{plot_impadapt2_sample}
\alias{plot_impadapt2_sample}
\title{Diagnostic Visualizations for Improved Adaptive Type-II Progressive Censoring}
\usage{
plot_impadapt2_sample(x, ...)
}
\arguments{
\item{x}{An object of class \code{"impadapt2_sample"}, \code{"impadapt2_mle"}, \code{"impadapt2_mpse"}, or \code{"impadapt2_bayes"}.}

\item{...}{Additional graphical arguments.}
}
\value{
No return value, called for side effects (plotting).
}
\description{
Generates diagnostic graphics (histogram, dot plot, empirical vs fitted survival curves, MCMC trace and autocorrelation plots).
}
\examples{
set.seed(123)
ge_cdf <- function(x, par) (1 - exp(-par[2] * x))^par[1]
ge_pdf <- function(x, par) par[1] * par[2] * exp(-par[2] * x) * (1 - exp(-par[2] * x))^(par[1] - 1)
ge_qdf <- function(p, par) - (1 / par[2]) * log(1 - p^(1 / par[1]))

samp <- r_impadapt2_censor(
  n = 20, m = 10, T1 = 0.8, T2 = 2.0,
  R = c(rep(1, 10)),
  pdf = ge_pdf, cdf = ge_cdf, qdf = ge_qdf,
  par = c(1.5, 0.8)
)
plot(samp)
}
